@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2015, Canari Project'
@@ -7,7 +7,7 @@ __credits__ = []
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -16,21 +16,18 @@ __all__ = [
     'create_package',
     'create_profile',
     'create_transform',
-    'csv2sheets',
+    'create_aws_lambda',
     'debug_transform',
     'dockerize_package',
     'framework',
     'generate_entities',
-    'help',
     'install_plume',
     'list_transforms',
-    'list_commands',
     'load_plume_package',
-    'mtgx2csv',
     'run_transform',
     'shell',
     'unload_plume_package',
     'version',
     'generate_entities_doc',
     'remote_transform'
-]
\ No newline at end of file
+]
