@@ -1,26 +1,22 @@
-from future.standard_library import install_aliases
-from past.builtins import basestring
-
-install_aliases()
+from six import string_types
+from six.moves.urllib import parse
 
 import sys
 import os
 import re
 import string
 
+from canari.mode import is_local_exec_mode, is_remote_exec_mode
+from canari.utils.fs import PushDir
+from canari.resource import global_config
+from canari.utils.wordlist import wordlist
+
 if sys.version_info[0] > 2:
     from configparser import ConfigParser, NoOptionError, NoSectionError, BasicInterpolation
 else:
     # noinspection PyUnresolvedReferences
     from ConfigParser import SafeConfigParser, NoOptionError, NoSectionError
 
-from urllib.parse import urlparse
-
-from canari.mode import is_local_exec_mode, is_remote_exec_mode
-from canari.utils.fs import PushDir
-from canari.resource import global_config
-from canari.utils.wordlist import wordlist
-
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2015, Canari Project'
 __credits__ = []
@@ -28,14 +24,21 @@ __credits__ = []
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
     'CanariConfigParser',
     'load_config',
     'NoOptionError',
-    'NoSectionError'
+    'NoSectionError',
+    'SECTION_LOCAL',
+    'SECTION_REMOTE',
+    'OPTION_LOCAL_CONFIGS',
+    'OPTION_LOCAL_PATH',
+    'OPTION_REMOTE_CONFIGS',
+    'OPTION_REMOTE_PACKAGES',
+    'OPTION_REMOTE_PATH'
 ]
 
 SECTION_LOCAL = 'canari.local'
@@ -82,7 +85,7 @@ if sys.version_info[0] > 2:
 
         def _parse_value(self, value):
             if value.startswith('object://') and is_local_exec_mode():
-                r = urlparse(value)
+                r = parse.urlparse(value)
                 try:
                     v = r.path.lstrip('/')
                     m = __import__(r.netloc, globals(), locals(), [v])
@@ -151,7 +154,7 @@ if sys.version_info[0] > 2:
 
         def get_as_list(self, key):
             opt = self.__getitem__(key)
-            if isinstance(opt, basestring):
+            if isinstance(opt, string_types):
                 opt = [opt] if opt else []
             return opt
 
@@ -177,7 +180,7 @@ else:
 
         def _parse_value(self, value):
             if value.startswith('object://') and is_local_exec_mode():
-                r = urlparse(value)
+                r = parse.urlparse(value)
                 try:
                     v = r.path.lstrip('/')
                     m = __import__(r.netloc, globals(), locals(), [v])
@@ -246,7 +249,7 @@ else:
 
         def get_as_list(self, key):
             opt = self.__getitem__(key)
-            if isinstance(opt, basestring):
+            if isinstance(opt, string_types):
                 opt = [opt] if opt else []
             return opt
 
