@@ -1,10 +1,11 @@
-from past.builtins import basestring
-
-from subprocess import Popen
 import os
 import re
+from subprocess import Popen, PIPE
 
-from canari.mode import is_remote_exec_mode
+from canari.maltego.message import MaltegoMessage
+from six import string_types
+
+from canari.mode import is_remote_exec_mode, is_local_exec_mode
 from canari.resource import external_resource
 from canari.utils.stack import calling_package
 
@@ -15,7 +16,7 @@ __credits__ = []
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -23,7 +24,9 @@ __all__ = [
     'Deprecated',
     'EnableRemoteExecution',
     'EnableDebugWindow',
-    'ExternalCommand'
+    'ExternalCommand',
+    'RequestFilter',
+    'classproperty'
 ]
 
 
@@ -91,15 +94,17 @@ class RequestFilter(object):
 
     def __call__(self, transform):
         if callable(filter):
-            if self.remote_only and is_remote_exec_mode():
-                orig_do_transform = transform.do_transform
+            if self.remote_only and not is_remote_exec_mode():
+                return transform
 
-                def do_transform(self_, request, response, config):
-                    if self.filter.__call__(request, response, config):
-                        return response
-                    return orig_do_transform(self_, request, response, config)
+            orig_do_transform = transform.do_transform
 
-                transform.do_transform = do_transform
+            def do_transform(self_, request, response, config):
+                if self.filter.__call__(request, response, config):
+                    return response
+                return orig_do_transform(self_, request, response, config)
+
+            transform.do_transform = do_transform
             return transform
         raise ValueError('Expected callable (got %s instead).' % type(self.filter).__name__)
 
@@ -126,30 +131,28 @@ class ExternalCommand(object):
         if args is None:
             args = []
         self.args = []
+        self.env = os.environ.copy()
 
         if interpreter:
             self.args.append(interpreter)
-            libpath = external_resource(
+            lib_path = external_resource(
                 os.path.dirname(program),
                 '%s.resources.external' % calling_package()
             )
             if interpreter.startswith('perl') or interpreter.startswith('ruby'):
-                self.args.append('-I%s' % libpath)
+                self.args.append('-I%s' % lib_path)
             elif interpreter.startswith('java'):
-                self.args.extend(['-cp', libpath])
+                self.args.extend(['-cp', lib_path])
+            elif interpreter.startswith('python'):
+                self.env['PYTHONPATH'] = ':'.join([self.env['PYTHONPATH'], lib_path])
 
         if ' ' in program:
             raise ValueError('Transform name %r cannot have spaces.' % program)
         else:
-            self.args.append(
-                external_resource(
-                    program,
-                    '%s.resources.external' % calling_package()
-                )
-            )
+            self.args.append(external_resource(program))
 
-        if isinstance(args, basestring):
-            self.args = re.split(r'\s+', args)
+        if isinstance(args, string_types):
+            self.args.extend(re.split(r'\s+', args))
         else:
             self.args.extend(args)
 
@@ -164,6 +167,19 @@ class ExternalCommand(object):
                      for k, v in request.entity.fields.items()]
                 )
             )
-        p = Popen(self.args)
-        p.communicate()
-        exit(p.returncode)
+        if is_local_exec_mode():
+            p = Popen(self.args, env=self.env)
+            p.communicate()
+            exit(p.returncode)
+        else:
+            p = Popen(self.args, env=self.env, stdout=PIPE)
+            out, _ = p.communicate()
+            return MaltegoMessage.parse(out)
+
+
+class classproperty(object):
+    def __init__(self, fget):
+        self.fget = fget
+
+    def __get__(self, instance, owner):
+        return self.fget(owner)
