@@ -15,7 +15,7 @@ __credits__ = []
 __license__ = 'GPLv3'
 __version__ = '0.3'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -23,7 +23,9 @@ __all__ = [
     'VisibilityType',
     'BuiltInTransformSets',
     'Set',
+    'MaltegoElement',
     'Transform',
+    'MaltegoEntity',
     'TransformSet',
     'InputConstraint',
     'OutputEntity',
