@@ -1,25 +1,32 @@
-from past.builtins import basestring, long
+import base64
+import gzip
+import json
+
+from past.builtins import long
 from future.utils import with_metaclass
 
-from collections import Iterable
+from collections import Iterable, OrderedDict
 from datetime import datetime, date, timedelta
 from numbers import Number
 import re
 
+from six import string_types
+
 from canari.maltego.oxml import MaltegoElement, fields as fields_
 
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2015, Canari Project'
-__credits__ = []
+__credits__ = ['Jakub Burgis', 'mshirley', 'Christophe Vandeplas']
 
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
+    'CompressedEntityField',
     'MaltegoException',
     'MaltegoTransformExceptionMessage',
     'MaltegoTransformRequestMessage',
@@ -28,6 +35,7 @@ __all__ = [
     'Field',
     'UIMessageType',
     'UIMessage',
+    'Unknown',
     'MaltegoTransformResponseMessage',
     'MaltegoMessage',
     'StringEntityField',
@@ -44,7 +52,14 @@ __all__ = [
     'ColorEntityField',
     'ArrayEntityField',
     'Entity',
-    'Limits'
+    'Limits',
+    'ValidationError',
+    'ElementType',
+    'Bookmark',
+    'LinkColor',
+    'LinkLabel',
+    'LinkStyle',
+    'EntityTypeFactory'
 ]
 
 
@@ -56,7 +71,7 @@ class MaltegoException(MaltegoElement, Exception):
     value = fields_.String(tagname='.')
     code = fields_.Integer(attrname='code', required=False)
 
-    def __init__(self, value):
+    def __init__(self, value=None):
         super(MaltegoElement, self).__init__(value=value)
 
     def __str__(self):
@@ -93,7 +108,7 @@ class Label(MaltegoElement):
     source of input.
     """
     def __init__(self, name=None, value=None, **kwargs):
-        super(Label, self).__init__(name=name, value=value, **kwargs)
+        super(Label, self).__init__(name=name, value=value or '', **kwargs)
 
     value = fields_.CDATA(tagname='.')
     type = fields_.String(attrname='Type', default='text/text')
@@ -124,8 +139,8 @@ class _Entity(MaltegoElement):
         tagname = 'Entity'
 
     type = fields_.String(attrname='Type')
-    fields = fields_.Dict(Field, key='name', tagname='AdditionalFields', required=False)
-    labels = fields_.Dict(Label, key='name', tagname='DisplayInformation', required=False)
+    fields = fields_.Dict(Field, key='name', tagname='AdditionalFields', required=False, dictclass=OrderedDict)
+    labels = fields_.Dict(Label, key='name', tagname='DisplayInformation', required=False, dictclass=OrderedDict)
     value = fields_.String(tagname='Value')
     weight = fields_.Integer(tagname='Weight', default=1)
     icon_url = fields_.String(tagname='IconURL', required=False)
@@ -222,6 +237,43 @@ class StringEntityField(object):
         return self.error_msg.format(field=field, value=value, **extras)
 
 
+class CompressedEntityField(StringEntityField):
+
+    error_msg = 'The field value ({value!r}) set for field {field!r} is not a serializable object.'
+
+    def __init__(self, name, compression=gzip, serdes=json, **extras):
+        super(CompressedEntityField, self).__init__(name, **extras)
+        self.compression = compression
+        self.serdes = serdes
+
+    def __get__(self, obj, objtype):
+        if obj is None:
+            return self
+        value = super(CompressedEntityField, self).__get__(obj, objtype)
+        try:
+            return self.serdes.loads(
+                self.compression.decompress(
+                    base64.decodebytes(
+                        bytes(value, 'utf8')
+                    )
+                )
+            ) if value is not None else None
+        except:
+            raise ValidationError(self.get_error_msg(self.display_name or self.name, value))
+
+    def __set__(self, obj, value):
+        if not isinstance(value, (dict, list)):
+            raise ValidationError(self.get_error_msg(self.display_name or self.name, value))
+        value = base64.encodebytes(
+            self.compression.compress(
+                bytes(
+                    self.serdes.dumps(value), 'utf8'
+                )
+            )
+        ).decode('utf8')
+        super(CompressedEntityField, self).__set__(obj, value)
+
+
 class EnumEntityField(StringEntityField):
 
     error_msg = 'Invalid value ({value!r}) set for field {field!r}. Expected one of these values: {expected!r}.'
@@ -229,21 +281,21 @@ class EnumEntityField(StringEntityField):
     def __init__(self, name, choices=None, **extras):
         if not choices:
             raise ValueError('You must specify a non-empty set of choices.')
-        self.choices = [str(c) if not isinstance(c, basestring) else c for c in choices]
+        self.choices = [str(c) if not isinstance(c, string_types) else c for c in choices]
         super(EnumEntityField, self).__init__(name, **extras)
 
     def __get__(self, obj, objtype):
         if obj is None:
             return self
         c = super(EnumEntityField, self).__get__(obj, objtype)
-        if c is not None and not isinstance(c, basestring):
+        if c is not None and not isinstance(c, string_types):
             c = str(c)
         if c and c not in self.choices:
             raise ValidationError(self.get_error_msg(self.display_name or self.name, c, expected=self.choices))
         return c
 
     def __set__(self, obj, val):
-        val = str(val) if not isinstance(val, basestring) else val
+        val = str(val) if not isinstance(val, string_types) else val
         if val not in self.choices:
             raise ValidationError(self.get_error_msg(self.display_name or self.name, val, expected=self.choices))
         super(EnumEntityField, self).__set__(obj, val)
@@ -422,7 +474,7 @@ class RegexEntityField(StringEntityField):
         return v
 
     def __set__(self, obj, val):
-        if not isinstance(val, basestring):
+        if not isinstance(val, string_types):
             val = str(val)
         if not self.matcher.match(val):
             raise ValidationError(self.get_error_msg(self.display_name or self.name, val, pattern=self.matcher.pattern))
@@ -466,7 +518,7 @@ class ElementType(object):
     @staticmethod
     def matches_type(type_, value):
         return (type_ is ElementType.int and isinstance(value, int)) or \
-               (type_ is ElementType.string and isinstance(value, basestring)) or \
+               (type_ is ElementType.string and isinstance(value, string_types)) or \
                (type_ is ElementType.boolean and isinstance(value, bool)) or \
                ((type_ is ElementType.float or type_ is ElementType.double) and isinstance(value, float)) or \
                (type_ is ElementType.date and isinstance(value, date))
@@ -550,7 +602,7 @@ class EntityTypeFactory(type):
 
     @classmethod
     def create(mcs, entity_type):
-        return mcs.registry[entity_type]
+        return mcs.registry.get(entity_type)
 
 
 class Bookmark:
@@ -590,6 +642,12 @@ class LinkColor:
     Pink = '#FEAFCA'
 
 
+class LinkDirection:
+    InputToOutput = 'input-to-output'
+    OutputToInput = 'output-to-input'
+    Bidirectional = 'bidirectional'
+
+
 class Entity(with_metaclass(EntityTypeFactory, object)):
 
     _namespace_ = None
@@ -613,6 +671,9 @@ class Entity(with_metaclass(EntityTypeFactory, object)):
                                           LinkColor.Orange, LinkColor.DarkGreen, LinkColor.NavyBlue, LinkColor.Magenta,
                                           LinkColor.Cyan, LinkColor.Lime, LinkColor.Yellow, LinkColor.Pink],
                                  matching_rule=MatchingRule.Loose)
+    link_direction = EnumEntityField('link#maltego.link.direction', display_name='Link Direction',
+                                     choices=[LinkDirection.InputToOutput, LinkDirection.OutputToInput,
+                                              LinkDirection.Bidirectional], matching_rule=MatchingRule.Loose)
 
     def __init__(self, value='', **kwargs):
         if isinstance(value, _Entity):
@@ -700,6 +761,17 @@ class Entity(with_metaclass(EntityTypeFactory, object)):
         else:
             self._entity.fields[key].value = value
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        pass
+
+
+class Unknown(Entity):
+    _category_ = 'Unknown'
+    _namespace_ = 'maltego'
+
 
 class MaltegoTransformRequestMessage(MaltegoElement):
 
@@ -731,7 +803,7 @@ class MaltegoTransformRequestMessage(MaltegoElement):
     @property
     def entities(self):
         if not self._entities:
-            self._entities = [EntityTypeFactory.create(e.type)(e) for e in self.__entities]
+            self._entities = [(EntityTypeFactory.create(e.type) or Unknown)(e) for e in self.__entities]
         return self._entities
 
     @property
@@ -745,6 +817,10 @@ class MaltegoTransformRequestMessage(MaltegoElement):
             return self._parameters['canari.local.arguments'].value
         return self._parameters
 
+    @property
+    def settings(self):
+        return {k: v.value for k, v in self._parameters.items()}
+
 
 class MaltegoMessage(MaltegoElement):
     """This is the root element for all Maltego request, response, and exception messages that are exchanged between the
