@@ -7,7 +7,7 @@ __credits__ = []
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -26,4 +26,4 @@ class MaltegoElement(Model):
         return self
 
     def __add__(self, other):
-        return self.__iadd__(other)
\ No newline at end of file
+        return self.__iadd__(other)
