@@ -1,16 +1,16 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
-__credits__ = ['Nadeem Douba']
+__credits__ = []
 
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
     'maltego',
     'transform'
-]
\ No newline at end of file
+]
