@@ -1,5 +1,7 @@
 from __future__ import print_function
 
+from future.builtins import bytes
+
 import os
 import re
 import sys
@@ -9,7 +11,7 @@ from distutils.version import LooseVersion
 from importlib import import_module
 from zipfile import ZipFile, ZIP_STORED
 
-from past.builtins import basestring
+from six import string_types
 from safedexml import Model
 
 from canari.maltego.configuration import (TransformSettings, CmdLineTransformPropertySetting, InputConstraint, Set,
@@ -19,17 +21,17 @@ from canari.maltego.configuration import (TransformSettings, CmdLineTransformPro
                                           CmdParmTransformProperty, TransformSet, Transform, MaltegoServer, Protocol,
                                           Authentication, EntityCategory, Properties, attributes, fileobject, attr,
                                           MaltegoEntity)
-from canari.question import parse_int
+from canari.question import prompt_menu
 from canari.utils.common import find_dispatcher
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
-__credits__ = ['Nadeem Douba']
+__credits__ = []
 
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -253,7 +255,7 @@ class MaltegoDistribution(object):
             return os.path.join(maltego_base_dir, vs[0])
         elif vs:
             print('Multiple versions of Maltego detected: ', file=sys.stderr)
-            r = parse_int('Please select which version you wish to use', ['Maltego %s' % i for i in vs])
+            r = prompt_menu('Please select which version you wish to use', ['Maltego %s' % i for i in vs])
             return os.path.join(maltego_base_dir, vs[int(r)])
         print('Could not automatically find Maltego\'s settings directory. '
               'Use the -w parameter to specify its location, instead.', file=sys.stderr)
@@ -283,21 +285,20 @@ class MaltegoDistribution(object):
     def _get_module_author(self, module_name):
         return getattr(import_module(module_name), '__author__', '')
 
-    def add_transform(self, working_dir, transform_repository, transform_class, server=None):
+    def add_transform(self, working_dir, transform_repository, transform, server=None):
         transform_repository_dir = self.get_transform_repository_dir(transform_repository)
 
-        transform = transform_class()
-        name = '.'.join([transform_class.__module__, transform_class.__name__])
-        author = transform.author or self._get_module_author(transform.__module__)
+        py_name = '.'.join([transform.__module__, transform.__name__])
+        author = transform.author
         transform_id = transform.name
         input_set = transform.transform_set
         input_entity = transform.input_type
 
         if transform.name in self.transform_uuids:
-            print('WARNING: Previous declaration of %s in transform %s. Overwriting...' % (transform_id, name),
+            print('WARNING: Previous declaration of %s in transform %s. Overwriting...' % (transform_id, py_name),
                   file=sys.stderr)
         else:
-            print('Installing transform %s from %s...' % (transform_id, name), file=sys.stderr)
+            print('Installing transform %s from %s...' % (transform_id, py_name), file=sys.stderr)
 
         sets = None
         if input_set:
@@ -334,7 +335,7 @@ class MaltegoDistribution(object):
 
         transform_settings_def = TransformSettings(properties=[
             CmdLineTransformPropertySetting(find_dispatcher()),
-            CmdParmTransformPropertySetting(name),
+            CmdParmTransformPropertySetting(py_name),
             CmdCwdTransformPropertySetting(working_dir),
             CmdDbgTransformPropertySetting(transform.debug)
         ])
@@ -408,14 +409,14 @@ class MaltegoDistribution(object):
         self.write_file(dst, contents)
 
     def add_entity(self, entity):
-        if isinstance(entity, basestring):
+        if isinstance(entity, string_types):
             entity = MaltegoEntity.parse(entity)
         if not isinstance(entity, MaltegoEntity):
             raise TypeError('Expected str or MaltegoEntity, not %s', type(entity).__name__)
         entity_category_dir = self.get_entity_category_dir(entity.category)
         entity_filename = '%s.entity' % self.path_join(entity_category_dir, entity.id)
         print('Installing entity %s to %s...' % (entity.id, entity_filename), file=sys.stderr)
-        self.write_file(entity_filename, entity.render(fragment=True, pretty=True))
+        self.write_file(entity_filename, entity.render(encoding='utf-8', fragment=True, pretty=True))
 
     def path_join(self, *args):
         return os.path.join(*args)
@@ -426,7 +427,7 @@ class MaltegoDistribution(object):
                                       'not support direct management of any files within the configuration directory.')
         with open(filename, 'w') as f:
             if isinstance(contents, Model):
-                f.write(contents.render(fragment=True, pretty=True))
+                f.write(contents.render(encoding='utf-8', fragment=True, pretty=True))
             else:
                 f.write(contents)
 
@@ -436,7 +437,7 @@ class MaltegoDistribution(object):
     def _write_pending(self):
         nbattrs = self.path_join(self.machines_dir, '.nbattrs')
         with open(nbattrs, mode='w') as f:
-            f.write(self._machine_nbattr.render(fragment=True, pretty=True))
+            f.write(self._machine_nbattr.render(encoding='utf-8', fragment=True, pretty=True))
 
     def remove_file(self, filename):
         if os.path.lexists(filename):
@@ -478,6 +479,8 @@ class MtzZipFile(object):
         return namelist
 
     def writestr(self, zinfo_or_arcname, bytes_):
+        if isinstance(bytes_, string_types):
+            bytes_ = bytes(bytes_, 'utf8')
         if self._is_closed:
             raise RuntimeError('Attempt to read ZIP archive that was already closed')
         if self.mode == 'r':
@@ -486,7 +489,7 @@ class MtzZipFile(object):
         realdir = os.path.dirname(realpath)
         if not os.path.isdir(realdir):
             os.makedirs(realdir)
-        with open(realpath, mode='w') as f:
+        with open(realpath, mode='wb') as f:
             f.write(bytes_)
 
     def removefile(self, zinfo_or_arcname):
@@ -699,7 +702,7 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
         if '\\' in zinfo_or_arcname:
             zinfo_or_arcname.replace('\\', '/')
         if isinstance(contents, Model):
-            contents = contents.render(fragment=True, pretty=True)
+            contents = contents.render(encoding='utf-8', fragment=True, pretty=True)
         self.writestr(zinfo_or_arcname, contents)
 
     def add_transform_to_set(self, transform_id, transform_set):
@@ -787,22 +790,24 @@ class MtzDistribution(MtzZipFile, MaltegoDistribution):
                 self._append_transform_set(mtz_file.read_file(f))
 
     def add_entity(self, entity):
-        if isinstance(entity, basestring):
+        if isinstance(entity, string_types):
             entity = MaltegoEntity.parse(entity)
         if not isinstance(entity, MaltegoEntity):
             raise TypeError('Expected str or MaltegoEntity, not %s', type(entity).__name__)
         self.add_entity_category(entity.category)
         entity_filename = '%s.entity' % self.path_join(self.entities_dir, entity.id)
         print('Installing entity %s to %s...' % (entity.id, entity_filename), file=sys.stderr)
-        self.write_file(entity_filename, entity.render(fragment=True, pretty=True))
+        self.write_file(entity_filename, entity.render(encoding='utf-8', fragment=True, pretty=True))
 
     def path_join(self, *args):
         return '/'.join(args)
 
-    def read_file(self, filename):
+    def read_file(self, filename, decode=True):
+        if decode:
+            return self.read(filename).decode('utf8')
         return self.read(filename)
 
     def close(self):
         if self.mode != 'r':
             self._write_pending()
-        super(MtzDistribution, self).close()
\ No newline at end of file
+        super(MtzDistribution, self).close()
