@@ -1,32 +1,32 @@
 from __future__ import print_function
-from past.builtins import basestring
 
 import importlib
-from io import FileIO
-from pkgutil import iter_modules
+import os
 import string
 import sys
-import os
-from importlib import import_module
+from pkgutil import iter_modules
+
+import click
 from mrbob.configurator import Configurator
+from six import string_types
 from pkg_resources import resource_listdir, resource_filename
 
-from canari.pkgutils.maltego import MaltegoDistribution, MtzDistribution
-from canari.maltego.transform import Transform
-from canari.maltego.message import EntityTypeFactory
-from canari.question import parse_bool
 from canari.config import CanariConfigParser, OPTION_LOCAL_CONFIGS, SECTION_LOCAL, OPTION_REMOTE_PACKAGES, \
     SECTION_REMOTE, OPTION_REMOTE_CONFIGS
+from canari.maltego.message import EntityTypeFactory
+from canari.maltego.transform import Transform
+from canari.pkgutils.maltego import MaltegoDistribution, MtzDistribution
+from canari.project import CanariProject
 from canari.utils.fs import PushDir
 
 __author__ = 'Nadeem Douba'
 __copyright__ = 'Copyright 2012, Canari Project'
-__credits__ = ['Nadeem Douba']
+__credits__ = []
 
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -62,33 +62,48 @@ class TransformDistribution(object):
         self._package_name = package_name.replace('.transforms', '') \
             if package_name.endswith('.transforms') else package_name
 
-        self._package = import_module(self.name)
-
-        print('Looking for transforms in %s...' % self.name, file=sys.stderr)
         try:
-            self.import_package(self._package)
-        except ImportError as e:
+            self._package = importlib.import_module(self.name)
+        except ImportError or ModuleNotFoundError as e:
             raise ImportError("Does not appear to be a valid canari package. "
-                              "Couldn't import the '%s.transforms' package in '%s'. Error message: %s" %
+                              "Couldn't import the '%s' module in '%s'. Error message: %s" %
                               (self.name, self.name, e))
 
-        self._transforms = list(self.find_all_subclasses(Transform))
-        self._remote_transforms = [t for t in self._transforms if t.remote]
+        self._package_path = os.path.abspath(os.path.dirname(self._package.__file__))
+        self._default_prefix = os.path.join(os.path.expanduser('~'), '.canari') if self.is_site_package else os.getcwd()
         self._config = '%s.conf' % self.name
         self._resources = '%s.resources' % self.name
-        self._package_path = os.path.abspath(self._package.__path__[0])
-        self._default_prefix = os.path.join(os.path.expanduser('~'), '.canari') if self.is_site_package else os.getcwd()
-        self._entities = list({v for v in EntityTypeFactory.registry.values()
-                               if v.__module__.startswith(self._package_name)})
         self._author = getattr(self._package, '__author__', '')
         self._email = getattr(self._package, '__email__', '')
-        try:
-            self._machines = [
-                m for m in resource_listdir(self.get_resource_module('maltego'), '') if m.endswith('.machine')]
-        except ImportError:
+
+        if self.name == 'canari':
+            self._transforms = []
+            self._remote_transforms = []
             self._machines = []
-        if self._package_name != 'canari' and not self.has_transforms:
-            raise ValueError('Error: no transforms found...')
+            # Import all the entities from the fixed location
+            importlib.import_module('canari.maltego.entities')
+            self._entities = list({
+                v for v in EntityTypeFactory.registry.values() if v.__module__.startswith(self._package_name)})
+        else:
+            print('Looking for transforms in %s...' % self.name, file=sys.stderr)
+            try:
+                self.import_package(self._package)
+            except ImportError or ModuleNotFoundError as e:
+                raise ImportError("Does not appear to be a valid canari package. "
+                                  "Couldn't import the '%s.transforms' package in '%s'. Error message: %s" %
+                                  (self.name, self.name, e))
+
+            self._transforms = list(self.find_all_subclasses(Transform))
+            self._remote_transforms = [t for t in self._transforms if t.remote]
+            self._entities = list({v for v in EntityTypeFactory.registry.values()
+                                   if v.__module__.startswith(self._package_name)})
+            try:
+                self._machines = [
+                    m for m in resource_listdir(self.get_resource_module('maltego'), '') if m.endswith('.machine')]
+            except ImportError or ModuleNotFoundError:
+                self._machines = []
+            if not self.has_transforms:
+                raise ValueError('Error: no transforms found...')
         print('Package loaded.', file=sys.stderr)
 
     @property
@@ -162,9 +177,8 @@ class TransformDistribution(object):
         return '%s.%s' % (self._resources, name)
 
     @staticmethod
-    def _write_config(src, dst, **kwargs):
-        if os.path.lexists(dst) and not \
-                parse_bool('%s already exists. Would you like to overwrite it?' % dst, default=False):
+    def _write_config(src, dst, defaults=False, **kwargs):
+        if not TransformDistribution._check_file_exists(dst, defaults):
             return
 
         print('Writing %s to %s' % (src, dst), file=sys.stderr)
@@ -189,7 +203,7 @@ class TransformDistribution(object):
         prefix = pkg.__name__
 
         if prefix == 'canari' and not cls._is_package_loaded('canari.maltego.entities'):
-            import canari.maltego.entities
+            pass
         else:
             for _, module_name, is_pkg in iter_modules(pkg.__path__):
                 module_name = '.'.join([prefix, module_name])
@@ -207,7 +221,8 @@ class TransformDistribution(object):
             for sub_subclass in self.find_all_subclasses(subclass):
                 yield sub_subclass
 
-    def _update_config(self, canari_config, load=True, remote=False):
+    def _update_config(self, canari_config, load=True, remote=False, **kwargs):
+
         with PushDir(os.path.dirname(canari_config)):
 
             config = CanariConfigParser()
@@ -224,6 +239,9 @@ class TransformDistribution(object):
             configs = config.get_as_list(configs_option)
 
             if load:
+                for (k, v) in kwargs.get('additional_options', {}).items():
+                    config['.'.join([config_section, k])] = v
+
                 if self.config_file not in configs:
                     print('Updating %s...' % canari_config, file=sys.stderr)
                     configs.append(self.config_file)
@@ -248,30 +266,35 @@ class TransformDistribution(object):
 
             config.write(open(canari_config, mode='w'))
 
-    def configure(self, install_prefix, load=True, remote=False, defaults=False, **kwargs):
-        if load:
-            dst = os.path.join(install_prefix, 'canari.conf')
-            if os.path.lexists(dst) and not defaults and \
-                    parse_bool('%s already exists. Would you like to overwrite it?' % dst, default=False):
-                print('Writing fresh copy of canari.conf to %r...' % dst, file=sys.stderr)
-                variables = {
-                    'canari.command': ' '.join(sys.argv),
-                    'profile.config': self.config_file if self.name != 'canari' else '',
-                    'profile.path': '${PATH},/usr/local/bin,/opt/local/bin' if os.name == 'posix' else ''
-                }
+    @staticmethod
+    def _check_file_exists(dst, defaults=False):
+        return not os.path.lexists(dst) or \
+               (not defaults and
+                click.confirm('%s already exists. Would you like to overwrite it?' % dst, default=False))
 
-                configurator = Configurator('canari.resources.templates:create_profile',
-                                            install_prefix,
-                                            {'non_interactive': True, 'remember_answers': True},
-                                            variables=variables)
-                configurator.render()
-                return
+    def configure(self, install_prefix, load=True, remote=False, defaults=False, **kwargs):
+        dst_canari_conf = os.path.join(install_prefix, 'canari.conf')
+        if load and self._check_file_exists(dst_canari_conf, defaults):
+            print('Writing fresh copy of canari.conf to %r...' % dst_canari_conf, file=sys.stderr)
+            variables = {
+                'canari.command': ' '.join(sys.argv),
+                'profile.config': self.config_file if self.name != 'canari' else '',
+                'profile.path': '${PATH},/usr/local/bin,/opt/local/bin' if os.name == 'posix' else ''
+            }
+
+            configurator = Configurator('canari.resources.templates:create_profile',
+                                        install_prefix,
+                                        {'non_interactive': True, 'remember_answers': True},
+                                        variables=variables)
+            configurator.render()
 
         if self._package_name != 'canari':
+            dst_package_conf = os.path.join(install_prefix, self.config_file)
             if load:
+                print('Copying %r to %r...' % (self.config_file, dst_package_conf))
                 package_config = resource_filename(self.get_resource_module('etc'), self.config_file)
-                self._write_config(package_config, os.path.join(install_prefix, self.config_file))
-            self._update_config(os.path.join(install_prefix, 'canari.conf'), load, remote)
+                self._write_config(package_config, dst_package_conf, defaults)
+            self._update_config(dst_canari_conf, load, remote, **kwargs)
 
     def _init_install_prefix(self, install_prefix):
         if not install_prefix:
@@ -280,8 +303,8 @@ class TransformDistribution(object):
             os.makedirs(install_prefix)
         return install_prefix
 
-    def install(self, install_prefix, distribution, configure=True, is_remote=False):
-        if isinstance(distribution, basestring) or not distribution:
+    def install(self, install_prefix, distribution, configure=True, is_remote=False, in_project=False):
+        if isinstance(distribution, string_types) or not distribution:
             distribution = MaltegoDistribution(distribution)
         if not isinstance(distribution, MtzDistribution):
             if distribution.version >= '3.4.0':
@@ -290,14 +313,16 @@ class TransformDistribution(object):
 
         install_prefix = self._init_install_prefix(install_prefix)
 
-        self._install_transforms(install_prefix, distribution)
+        self._install_transforms(install_prefix, distribution, in_project)
         self._install_entities(distribution)
         self._install_machines(distribution)
 
         if configure:
             self.configure(install_prefix, remote=is_remote)
 
-    def _install_transforms(self, prefix, distribution):
+    def _install_transforms(self, prefix, distribution, in_project=False):
+        if in_project:
+            prefix = CanariProject().src_dir
         for transform in self.transforms:
             distribution.add_transform(prefix, 'Local', transform, server='Local')
 
@@ -314,7 +339,7 @@ class TransformDistribution(object):
             for icon_category in mtz.icon_categories:
                 icon_category_dir = distribution.get_icon_category_dir(icon_category)
                 for icon in mtz.get_icons_by_category(icon_category):
-                    data = mtz.read_file(icon)
+                    data = mtz.read_file(icon, False)
                     p = distribution.path_join(icon_category_dir, os.path.basename(icon))
                     print('Installing custom icon %s to %s...' % (icon, p), file=sys.stderr)
                     distribution.write_file(p, data)
@@ -361,11 +386,11 @@ class TransformDistribution(object):
         for transform in self.transforms:
             distribution.remove_transform('Local', transform, server='Local')
 
-    def create_profile(self, install_prefix, current_dir, configure=True):
-        mtz = os.path.join(current_dir, '%s.mtz' % self.name)
+    def create_profile(self, install_prefix, mtz_dir, configure=True, in_project=False):
+        mtz = os.path.join(mtz_dir, '%s.mtz' % self.name)
         print('Creating profile %s...' % mtz, file=sys.stderr)
         mtz = MtzDistribution(mtz, 'w')
-        self.install(install_prefix, mtz, configure)
+        self.install(install_prefix, mtz, configure, in_project=in_project)
         mtz.close()
 
         print("""
