@@ -5,7 +5,7 @@ __credits__ = []
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 
@@ -13,4 +13,4 @@ __all__ = [
     'fs',
     'stack',
     'wordlist'
-]
\ No newline at end of file
+]
