@@ -1,10 +1,7 @@
-from future.standard_library import install_aliases
-
-install_aliases()
+from __future__ import print_function
 
 import os
 import sys
-from io import FileIO
 
 from tempfile import NamedTemporaryFile, gettempdir
 from time import time
@@ -16,7 +13,7 @@ __credits__ = ['Andrew Udvare']
 __license__ = 'GPLv3'
 __version__ = '0.1'
 __maintainer__ = 'Nadeem Douba'
-__email__ = 'ndouba@gmail.com'
+__email__ = 'ndouba@redcanari.com'
 __status__ = 'Development'
 
 __all__ = [
@@ -101,11 +98,11 @@ else:
     from fcntl import flock, LOCK_EX, LOCK_NB, LOCK_SH, LOCK_UN
 
 
-class FileSemaphore(FileIO):
+class FileSemaphore(object):
 
     def __init__(self, name, mode='rb', buffering=True):
         self.locked = False
-        super(FileSemaphore, self).__init__(name, mode, buffering)
+        self._file = open(name, mode, buffering=buffering)
 
     def lockex(self, nb=False):
         flags = LOCK_EX
@@ -133,15 +130,18 @@ class FileSemaphore(FileIO):
             self.unlock()
 
     def close(self):
-        super(FileSemaphore, self).close()
+        self.file.close()
         if self.locked and not self.closed:
             self.unlock()
 
     def __exit__(self, *args):
-        super(FileSemaphore, self).__exit__(*args)
+        self.file.__exit__(*args)
         if self.locked and not self.closed:
             self.unlock()
 
+    def __getattr__(self, item):
+        return getattr(self._file, item)
+
 
 class FileMutex(FileSemaphore):
 
@@ -150,7 +150,7 @@ class FileMutex(FileSemaphore):
         self.lockex()
 
 
-def UniqueFile(self, name, delete=False):
+def UniqueFile(name, delete=False):
     n, e = os.path.splitext(name)
     f = NamedTemporaryFile(suffix=e, prefix='%s_' % n, delete=delete)
     if os.name == 'posix':
@@ -170,11 +170,13 @@ class PushDir(object):
         if os.path.lexists(self.cwd):
             os.chdir(self.cwd)
         else:
-            sys.stderr.write('WARNING: %r directory does not exist. Falling back to %r.' %
-                             (self.cwd, self.original_dir))
+            print(
+                'WARNING: %r directory does not exist. Falling back to %r.' % (self.cwd, self.original_dir),
+                file=sys.stderr
+            )
         return self
 
-    def __exit__(self, type_, value, tb):
+    def __exit__(self, *args):
         os.chdir(self.original_dir)
 
 
